OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "V teku je selitev. Počakajte, da se zaključi.",
    "Migration started …" : "Selitev je začeta ...",
    "Saved" : "Shranjeno",
    "Sending…" : "Poteka pošiljanje ...",
    "Email sent" : "Elektronsko sporočilo je poslano",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
    "Valid until {date}" : "Veljavno do {date}",
    "Delete" : "Izbriši",
    "Local" : "Krajevno",
    "Private" : "Zasebno",
    "Only visible to local users" : "Vidno le krajevnim uporabnikom",
    "Contacts" : "Stiki",
    "Visible to local users and to trusted servers" : "Vidno le krajevnim uporabnikom in odobrenim strežnikom",
    "Public" : "Javno",
    "Verify" : "Overi",
    "Verifying …" : "Poteka overjanje ...",
    "Unable to change password" : "Ni mogoče spremeniti gesla",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Slabo geslo",
    "So-so password" : "Šibko geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Select a profile picture" : "Izbor slike profila",
    "Week starts on {fdow}" : "Začetek tedna je {fdow}",
    "Groups" : "Skupine",
    "Group list is empty" : "Seznam skupin je prazen",
    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
    "You added {user} to group {group}" : "Uporabnika {user} ste dodali v skupino {group}",
    "An administrator added you to group {group}" : "Administrator vas je dodal v skupino {group}",
    "An administrator added {user} to group {group}" : "Administrator je dodal uporabnika {user} v skupino {group}",
    "{actor} changed your password" : "{actor} spremeni moje geslo",
    "You changed your password" : "Spremenili ste vaše geslo",
    "Your password was reset by an administrator" : "Skrbnik sistema je ponastavil staro geslo",
    "{actor} changed your email address" : "{actor} spremeni moj elektronski naslov",
    "Security" : "Varnost",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Spremenjeno je bilo <strong>geslo</strong> oziroma <strong>elektronski naslov</strong>",
    "Couldn't remove app." : "Programa ni mogoče odstraniti.",
    "Couldn't update app." : "Programa ni mogoče posodobiti.",
    "Wrong password" : "Napačno geslo",
    "No user supplied" : "Ni navedenega uporabnika",
    "Authentication error" : "Napaka overjanja",
    "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "nameščanje in posodabljanje programov prek programske zbirke ali zveznega oblaka",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "Invalid SMTP password." : "Neveljavno geslo SMTP",
    "Email setting test" : "Preizkus nastavitev elektronske pošte",
    "Well done, %s!" : "Odlično, %s!",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je prišlo do napake. Preverite nastavitve (napaka: %s).",
    "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
    "Invalid mail address" : "Neveljaven elektronski naslov",
    "Settings saved" : "Nastavitve so shranjene.",
    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Za overitev računa Twitter, objavite sporočilo (prepričajte se, da ni nobenega preloma vrstice):",
    "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
    "Set your password" : "Določitev gesla",
    "Install Client" : "Namesti odjemalca",
    "Create" : "Ustvari",
    "Change" : "Spremeni",
    "Unlimited" : "Neomejeno",
    "Nextcloud settings" : "Nastavitve Nextcloud",
    "Limit to groups" : "Omeji na skupine",
    "Save changes" : "Shrani spremembe",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Uradne programe razvijajo posamezniki, ki sodelujejo s skupnostjo. Paketi vključujejo osrednje zmožnosti programa, uporaba pa je namenjena tudi končnim uporabnikom.",
    "Official" : "Uradno",
    "Update to {version}" : "Posodobi na različico {version}",
    "Remove" : "Odstrani",
    "Disable" : "Onemogoči",
    "All" : "Vsi",
    "No results" : "Ni zadetkov",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja NextCloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja NextCloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerešenih odvisnosti:",
    "View in store" : "Pokaži v trgovini",
    "Visit website" : "Odpri spletno stran",
    "Report a bug" : "Pošlji poročilo o hrošču",
    "User documentation" : "Uporabniška dokumentacija",
    "Admin documentation" : "Skrbniška dokumentacija",
    "Developer documentation" : "Dokumentacija za razvijalce",
    "Update to {update}" : "Posodobi na {update}",
    "Results from other categories" : "Rezultati iskanja med drugimi kategorijami",
    "No apps found for your version" : "Za navedeni iskalni niz ni programov",
    "Disable all" : "Onemogoči vse",
    "Enable all" : "Omogoči vse",
    "Download and enable" : "Prejmi in omogoči",
    "Enable" : "Omogoči",
    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
    "Device settings" : "Nastavitve naprave",
    "Allow filesystem access" : "Dovoli dostop do datotečnega sistema",
    "Rename" : "Preimenuj",
    "Revoke" : "Prekliči",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Microsoft Edge",
    "Firefox" : "Mozilla Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome za Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "This session" : "Ta seja",
    "Device" : "Naprava",
    "Last activity" : "Zadnja dejavnost",
    "Devices & sessions" : "Naprave in seje",
    "Web, desktop and mobile clients currently logged in to your account." : "Spletne, namizne in mobilne naprave, ki so trenutno povezane z računom.",
    "Error while creating device token" : " Napaka med ustvarjanjem žetona naprave",
    "Error while deleting the token" : " Napaka med brisanjem žetona",
    "App name" : "Ime programa",
    "Create new app password" : "Ustvari novo geslo programa",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Done" : "Končano",
    "Copied!" : "Kopirano!",
    "Copy" : "Kopiraj",
    "New password" : "Novo geslo",
    "Add user in group" : "Dodaj uporabnika v skupino",
    "Select user quota" : "Izbor količinske omejitve uporabnika",
    "No language set" : "Jezik ni nastavljen",
    "Never" : "Nikoli",
    "Delete user" : "Izbriši uporabnika",
    "Disable user" : "Onemogoči uporabnika",
    "Enable user" : "Omogoči uporabnika",
    "Display name" : "Prikazno ime",
    "Email" : "Elektronski naslov",
    "Group admin for" : "Skrbnik skupine za",
    "Quota" : "Količinska omejitev",
    "Language" : "Jezik",
    "Storage location" : "Mesto shrambe",
    "Last login" : "Zadnja prijava",
    "Default language" : "Privzeti jezik",
    "Add a new user" : "Dodaj uporabnika",
    "No users in here" : "Ni še vključenih uporabnikov",
    "Default quota" : "Privzeta omejitev",
    "Common languages" : "Splošni jeziki",
    "All languages" : "Vsi jeziki",
    "Your apps" : "Vsi programi",
    "Active apps" : "Zagnani programi",
    "Disabled apps" : "Onemogočeni programi",
    "Updates" : "Posodobitve",
    "App bundles" : "Paketi programov",
    "New user" : "Nov uporabnik",
    "Default quota:" : "Privzeta količinska omejitev :",
    "Select default quota" : "Izbor količinske omejitve",
    "Show Languages" : "Pokaži jezike",
    "Show last login" : "Pokaži zadnjo prijavo",
    "Show user backend" : "Pokaži ozadnji program",
    "Remove group" : "Odstrani skupino",
    "Admins" : "Skrbniki",
    "Disabled users" : "Onemogočeni uporabniki",
    "Everyone" : "Vsi",
    "Add group" : "Dodaj skupino",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Program je omogočen, vendar zahteva posodobitev. Po nekaj sekundah boste preusmerjeni na stran za posodobitev.",
    "SSL Root Certificates" : "Korenska potrdila SSL",
    "Common Name" : "Splošno ime",
    "Valid until" : "Veljavno do",
    "Issued By" : "Izdajatelj",
    "Valid until %s" : "Veljavno do %s",
    "Import root certificate" : "Uvozi korensko potrdilo",
    "Administrator documentation" : "Skrbniška dokumentacija",
    "Forum" : "Forum",
    "None" : "Brez",
    "Login" : "Prijava",
    "Plain" : "Besedilno",
    "NT LAN Manager" : "Upravljalnik NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Poštni strežnik",
    "Open documentation" : "Odprta dokumentacija",
    "Send mode" : "Način pošiljanja",
    "Encryption" : "Šifriranje",
    "From address" : "Naslov pošiljatelja",
    "mail" : "pošta",
    "Authentication method" : "Način overitve",
    "Authentication required" : "Zahtevana je overitev",
    "Server address" : "Naslov strežnika",
    "Port" : "Vrata",
    "Credentials" : "Poverila",
    "SMTP Username" : "Uporabniško ime SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Test email settings" : "Preizkus nastavitev elektronske pošte",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Security & setup warnings" : "Varnost in namestitvena opozorila",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je pomembno, da je sistem pravilno nastavljen. Za pomoč pri preverjanju se samodejno izvajajo nekateri preizkusi. Več podrobnosti o tem je zabeleženih v dokumentaciji. ",
    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
    "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih je nekaj napak namestitve.",
    "There are some warnings regarding your setup." : "Med preverjanjem je bilo javljenih nekaj opozoril.",
    "Checking for system and security issues." : "Preverjanje sistemskih in varnostnih nastavitev.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Preverite varnost storitev Nextcloud s <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">preverjalnikom ↗</a>.",
    "Version" : "Različica",
    "Two-Factor Authentication" : "Dvo-stopenjska overitev",
    "Server-side encryption" : "Šifriranje na strežniku",
    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
    "Please read carefully before activating server-side encryption: " : "Pred omogočanjem strežniškega šifriranja pozorno preberite opombe:",
    "Be aware that encryption always increases the file size." : " Upoštevajte, da šifriranje poveča velikost datoteke.",
    "This is the final warning: Do you really want to enable encryption?" : "To je zadnje opozorilo. Ali res želite omogočiti šifriranje?",
    "Enable encryption" : "Omogoči šifriranje",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul za šifriranje ni naložen. Pred nadaljevanjem je treba modul določiti v seznamu programov.",
    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
    "Start migration" : "Začni selitev",
    "Background jobs" : "Opravila v ozadju",
    "Execute one task with each page loaded" : "Izvedi eno nalogo z vsako naloženo stranjo.",
    "Sharing" : "Souporaba",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Skrbnik lahko prilagodi možnosti souporabe. Več podrobnosti je zapisanih v dokumentaciji.",
    "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
    "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
    "Allow public uploads" : "Dovoli javno pošiljanje datotek v oblak",
    "Always ask for a password" : "Vedno zahtevaj za geslo",
    "Enforce password protection" : "Vsili zaščito z geslom",
    "Set default expiration date" : "Samodejno nastavi datuma poteka",
    "Expire after " : "Povezava naj poteče po",
    "days" : "dneh.",
    "Enforce expiration date" : "Vsili datum preteka",
    "Allow resharing" : "Dovoli nadaljnjo souporabo",
    "Allow sharing with groups" : "Dovoli souporabo s skupinami",
    "Restrict users to only share with users in their groups" : "Uporabnikom dovoli omogočanje souporabe le znotraj njihove skupine",
    "Exclude groups from sharing" : "Izloči izbrane skupine iz souporabe",
    "These groups will still be able to receive shares, but not to initiate them." : "Te skupine lahko sprejemajo mape v souporabo, nimajo pa dovoljenja za omogočanje souporabe.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Dovoli samodejno dokončanje uporabniškega imena v pogovornem oknu souporabe. Z onemogočeno možnostjo je treba v celoti vpisati uporabniško ime oziroma geslo.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Pokaži besedilo izjave o omejitvi odgovornosti na javnih povezavah za pošiljanje (če je onemogočen prikaz seznama datotek).",
    "This text will be shown on the public link upload page when the file list is hidden." : "Besedilo izjave o omejitvi odgovornosti, ki bo izpisano v oknu za pošiljanje, ko je možnost prikaza seznama datotek onemogočena.",
    "Default share permissions" : "Privzeta dovoljenja souporabe",
    "Personal" : "Osebno",
    "Administration" : "Skrbništvo",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Okolje razvija {communityopen}skupnost Nextcloud{linkclose}, {githubopen}izvorna koda{linkclose} pa je objavljena pod pogoji dovoljenja {licenseopen}AGPL{linkclose}.",
    "Follow us on Twitter" : "Sledite nam na Twitter!",
    "Follow us on Mastodon" : "Sledite nam na Mastodon",
    "Profile picture" : "Slika profila",
    "Upload new" : "Pošlji novo",
    "Select from Files" : "Izbor iz datotek",
    "Remove image" : "Odstrani sliko",
    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
    "Picture provided by original account" : "Slika iz originalnega računa",
    "Cancel" : "Prekliči",
    "Choose as profile picture" : "Izberi kot sliko profila",
    "Details" : "Podrobnosti",
    "You are a member of the following groups:" : "Omogočeno je članstvo v skupinah:",
    "You are using <strong>%s</strong>" : "Uporabljate <strong>%s</strong>",
    "Full name" : "Polno ime",
    "No display name set" : "Prikazno ime ni nastavljeno",
    "Your email address" : "Osebni elektronski naslov",
    "No email address set" : "Poštni naslov ni nastavljen",
    "For password reset and notifications" : "Za ponastavitev gesla in obveščanje",
    "Phone number" : "Telefonska številka",
    "Your phone number" : "Vaša telefonska številka",
    "Address" : "Naslov",
    "Your postal address" : "Vaš poštni naslov",
    "Website" : "Spletna stran",
    "Link https://…" : "Povezava https:// …",
    "Twitter" : "Račun Twitter",
    "Twitter handle @…" : "Twitter @ …",
    "Help translate" : "Sodelujte pri prevajanju",
    "Locale" : "Jezikovne nastavitve",
    "Current password" : "Trenutno geslo",
    "Change password" : "Spremeni geslo",
    "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
    "Disconnect" : "Prekinjeni povezavo",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "Error while loading browser sessions and device tokens" : " Napaka med nalaganjem sej brskalnika in žetonov naprave",
    "Afrikaans (Namibia)" : "Afrikanščina (Namibia)",
    "Afrikaans (South Africa)" : "Afrikanščina (Južna Afrika)",
    "Afrikaans" : "Afrikanščina",
    "Akan (Ghana)" : "Akanščina (Gana)",
    "Akan" : "Akanščina",
    "Albanian (Albania)" : "Albanščina (Albanija)",
    "Albanian" : "Albanščina",
    "Amharic (Ethiopia)" : "Amharščina (Etiopija)",
    "Amharic" : "Amharščina",
    "Arabic (Algeria)" : "Arabščina (Alžirija)",
    "Arabic (Bahrain)" : "Arabščina (Bahrain)",
    "Arabic (Egypt)" : "Arabščina (Egipt)",
    "Arabic (Iraq)" : "Arabščina (Irak)",
    "Arabic (Jordan)" : "Arabščina (Jordanija)",
    "Arabic (Kuwait)" : "Arabščina (Kuvajt)",
    "Arabic (Lebanon)" : "Arabščina (Libanon)",
    "Arabic (Libya)" : "Arabščina (Libija)",
    "Arabic (Morocco)" : "Arabščina (Maroko)",
    "Arabic (Oman)" : "Arabščina (Oman)",
    "Arabic (Qatar)" : "Arabščina (Katar)",
    "Arabic (Saudi Arabia)" : "Arabščina (Savdova arabija)",
    "Arabic (Sudan)" : "Arabščina (Sudan)",
    "Arabic (Syria)" : "Arabščina (Sirija)",
    "Arabic (Tunisia)" : "Arabščina (Tunizija)",
    "Arabic (United Arab Emirates)" : "Arabščina (Združeni Emirati)",
    "Arabic (Yemen)" : "Arabščina (Jemen)",
    "Arabic" : "Arabščina",
    "Armenian (Armenia)" : "Armenščina (Armenija)",
    "Armenian" : "Armenščina",
    "Assamese (India)" : "Asamščina (Indija)",
    "Assamese" : "Asamščina",
    "Asu (Tanzania)" : "Asujščina (Tanzanija)",
    "Asu" : "Asujščina",
    "English" : "Angleščina",
    "Esperanto" : "Esperanto",
    "Estonian" : "Estonščina",
    "Faroese" : "Farščina",
    "Finnish" : "Finščina",
    "French" : "Francoščina",
    "Serbian (Cyrillic)" : "Srbščina (cirilica)",
    "Serbian (Cyrillic, Bosnia and Herzegovina)" : "Srbščina (cirilica, Bosna in Hercegovina)",
    "Serbian (Cyrillic, Montenegro)" : "Srbščina (cirilica, Črna gora)",
    "Serbian (Cyrillic, Serbia)" : "Srbščina (cirilica, Srbija)",
    "Serbian (Latin)" : "Srbščina (latinica)",
    "Serbian (Latin, Bosnia and Herzegovina)" : "Srbščina (latinica, Bosna in Hercegovina)",
    "Serbian (Latin, Montenegro)" : "Srbščina (latinica, Črna gora)",
    "Serbian (Latin, Serbia)" : "Srbščina (latinica, Srbija)",
    "Slovenian (Slovenia)" : "Slovenščina (Slovenija)",
    "Slovenian" : "Slovenščina",
    "Somali (Djibouti)" : "Somalščina (Džibuti)",
    "Somali (Ethiopia)" : "Somalščina (Etiopija)",
    "Somali (Kenya)" : "Somalščina (Kenija)",
    "Somali (Somalia)" : "Somalščina (Somalija)",
    "Somali" : "Somalščina",
    "Spanish (Argentina)" : "Španščina (Argentina)",
    "Spanish (Bolivia)" : "Španščina (Bilovija)",
    "Spanish (Chile)" : "Španščina (Čile)",
    "Spanish (Colombia)" : "Španščina (Kolumbija)",
    "Spanish (Costa Rica)" : "Španščina (Kostarika)",
    "Spanish (Dominican Republic)" : "Španščina (Dominikanska republika)",
    "Spanish (Ecuador)" : "Španščina (Ekvador)",
    "Spanish (El Salvador)" : "Španščina (El Salvador)",
    "Spanish (Equatorial Guinea)" : "Španščina (Ekvatorialna Gvineja)",
    "Spanish (Guatemala)" : "Španščina (Gvatemala)",
    "Spanish (Honduras)" : "Španščina (Honduras)",
    "Spanish (Latin America)" : "Španščina (Latinska Amerika)",
    "Spanish (Mexico)" : "Španščina (Mehika)",
    "Spanish (Nicaragua)" : "Španščina (Nikaragva)",
    "Spanish (Panama)" : "Španščina (Panama)",
    "Spanish (Paraguay)" : "Španščina (Paragvaj)",
    "Spanish (Peru)" : "Španščina (Peru)",
    "Spanish (Puerto Rico)" : "Španščina (Portoriko)",
    "Spanish (Spain)" : "Španščina (Španija)",
    "Spanish (United States)" : "Španščina (Združene države Amerike)",
    "Spanish (Uruguay)" : "Španščina (Urugvaj)",
    "Spanish (Venezuela)" : "Španščina (Venezuela)",
    "Spanish" : "Španščina",
    "Store credentials" : "Shrani poverila",
    "Follow us on Google+" : "Sledite nam na Google+"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
